RunService class

Constructors

RunService(LumideContext context, ProjectService projectService, SdkManager sdkManager, DeviceService deviceService, TargetService targetService, DaemonService daemonService, LaunchConfigService launchConfigService)

Properties

channel → LumideOutputChannel?
no setter
context → LumideContext
final
daemonService DaemonService
final
deviceService DeviceService
final
hashCode int
The hash code for this object.
no setterinherited
isRunning bool
no setter
launchConfigService LaunchConfigService
final
projectService ProjectService
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdkManager SdkManager
final
targetService TargetService
final

Methods

attach() Future<void>
continueExecution() Future<void>
debug() Future<void>
dispose() Future<void>
evaluate(String expression, {int? frameId}) Future<LumideDebugEvaluationResult?>
getScopes(int frameId) Future<List<LumideDebugScope>>
getStackFrames() Future<List<LumideDebugStackFrame>>
getVariables(int variablesReference) Future<List<LumideDebugVariable>>
hotReload() Future<void>
hotRestart() Future<void>
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDevTools() Future<void>
openDevToolsInWebview() Future<void>
pauseExecution() Future<void>
refreshLaunchConfigurations() Future<void>
run() Future<void>
setBuildMode([String? mode, Map<String, int>? position]) Future<void>
setCustomToolArgs([String? rawArgs]) Future<void>
setFlavor([String? flavor]) Future<void>
stepInto() Future<void>
stepOut() Future<void>
stepOver() Future<void>
stop() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited