DaemonService class
Constructors
- DaemonService(LumideContext context, ProjectService projectService, SdkManager sdkManager, LogService logService)
Properties
- context → LumideContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool
-
no setter
- logService → LogService
-
final
-
onDaemonConnected
→ Stream<
Map< String, dynamic> > -
no setter
-
onDeviceAdded
→ Stream<
Map< String, dynamic> > -
no setter
-
onDeviceRemoved
→ Stream<
Map< String, dynamic> > -
no setter
- projectService → ProjectService
-
final
-
ready
→ Future<
void> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkManager → SdkManager
-
final
Methods
-
disableDevicePolling(
) → Future< void> -
dispose(
) → Future< void> -
enableDevicePolling(
) → Future< void> -
getDevices(
) → Future< List< Map< >String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serveDevTools(
) → Future< Map< String, dynamic> > -
start(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited