LaunchConfigService class
Constructors
- LaunchConfigService(LumideContext context, ProjectService projectService, void _log(String))
Properties
- context → LumideContext
-
final
-
entries
→ List<
VscodeLaunchEntry> -
The parsed launch configurations. Empty if no
.vscode/launch.jsonexists or if the file is malformed.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
onDidChange
↔ Future<
void> Function()? -
getter/setter pair
- projectService → ProjectService
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
fetchVariableContext(
) → Future< DynamicVariableContext> - Fetches the current editor state to resolve dynamic variables.
-
init(
) → Future< void> -
needsDynamicResolution(
VscodeLaunchEntry? entry, [Iterable< String?> additional = const []]) → bool -
Returns true if the given
entryor any of theadditionalstrings contain VS Code variables that depend on the active editor state. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reload(
) → Future< void> -
resolveAllVariables(
String value) → Future< String> -
resolveDynamicVariables(
String value, {DynamicVariableContext? ctx}) → Future< String> - Resolves dynamic VS Code variables that depend on the active editor state.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited